#!/bin/bash

# WAV-making script calling C function waveform
# Requires working libsndfile install, and uses the bash shell
#
# By Jason Pelc, December 2007
# For Physics 210, Stanford University, Fall 2007
#
# Modified March 30, 2008 to change WAV file production
#   technique.  Now uses the libsndfile package instead
#   of Octave.  

# Compile the program, setup destination directory:
gcc waveform.c -lm -o waveform
gcc sndfile.c -lsndfile -o asc2wav
rm -rf wavs
mkdir wavs

# Sampling rate: set in waveform.c
samplerate=44100

# Run the cases:
echo "d/L = 0.1 with dispersion"
./waveform 0.1 0.03
./asc2wav test.out 0p1_disp.wav $samplerate

echo "d/L = 0.1 without dispersion"
./waveform 0.1 0.0
./asc2wav test.out 0p1_nodisp.wav $samplerate

echo "d/L = 0.23 with dispersion"
./waveform 0.23 0.03
./asc2wav test.out 0p23_disp.wav $samplerate

echo "d/L = 0.23 without dispersion"
./waveform 0.23 0.0
./asc2wav test.out 0p23_nodisp.wav $samplerate

echo "d/L = 0.5 with dispersion"
./waveform 0.5 0.03
./asc2wav test.out 0p5_disp.wav $samplerate

echo "d/L = 0.5 without dispersion"
./waveform 0.5 0.0
./asc2wav test.out 0p5_nodisp.wav $samplerate

# Clean up:
rm test.out
mv *disp.wav wavs
