#include <stdio.h>
#include <math.h>
#include <stdlib.h>

/*	This is Jason's program to compute a guitar string waveform
	as a function of the plucked position and string anharmonicity

	Completed as Coursework for Physics 210

	12/07/07						 */

int main(int argc, char** argv) {

  /* Variable declarations */
  int nharm,i,nbeats,j,fs;
  double tfrac,f,gam,bpm,tmp;
  float d,b;
  char fname[100];

  /* Parameters controlling the sound output */
  fs = 44100;		/* Sampling frequency -- needs to match
			   value in makewav.m */
  gam = 1.7;		/* Decay constant -- increases with damping */
  f = 220.0;		/* Fundamental Frequency -- A below middle C */
  bpm = 80.0;           /* Tempo in beats per minute */

  /* Error checking: */
  if (argc != 3)
    {
      fprintf(stderr,"\nUsage : %s pluck_location inharmonicity\n",argv[0]);
      fprintf(stderr,"For example: %s 0.26 0.01\n\n\n",argv[0]);
      exit(0);
    }
  else
    {
      d = atof(argv[1]);
      b = atof(argv[2]);
    }
  
  
  /* Compute the harmonic spectrum, write to file */
  nharm = floor(fs/(2.0*f)); /* Set maximum harmonics to avoid aliasing */
  printf("Using %i harmonics \n",nharm);
  float An[nharm],dfn[nharm];
  printf("You made d = %.4f and b = %.4f\n",d,b);
  for(i=0; i < nharm; i++)
    {
      j = i + 1;
      tmp = 2/(pow(M_PI,2.0) * pow(j,2) * d * (1 - d) );
      tmp = tmp*sin(j*M_PI*d);
      An[i] = tmp;
/*       printf("%5i   %5.4f\n",j,An[i]); */
    }

  /* Compute the frequency spectrum */
  for (i=0; i < nharm; i++)
    {
      j = i+1;
      dfn[i] = sqrt(1.0 + j*j*b*b);
/*       printf("dfn[%i] = %f\n",i,dfn[i]); */
    }

  /* Open the writing file */
  FILE *fp;
  sprintf(fname,"test.out");
  fp = fopen(fname,"w");

  /* Compute the time series */
  int Nbeats,Nt,jh;
  double T,sj,f1,f2,f3,f4,t;
  Nbeats = 8;
  T = 60/bpm;
  Nt = fs*60/bpm;

  /* Make note 1 */
  f1 = f;
  for (i = 0; i < Nt; i++)
    {
      sj = 0.0;
      for (j = 0; j < nharm; j++)
	{
	  jh = j + 1;
 	  sj += An[j]*exp(-gam*jh*i/fs)*sin(2.0*M_PI*i*f*dfn[j]*jh/fs);
	}
      fprintf(fp,"%.6f\n",sj);
    }
  
  /* Make note 2 */
  f2 = f*5.0/4.0;
  for (i = 0; i < Nt; i++)
    {
      sj = 0.0;
      for (j = 0; j < nharm; j++)
	{
	  jh = j + 1;
 	  sj += An[j]*exp(-gam*jh*i/fs)*sin(2.0*M_PI*i*f2*dfn[j]*jh/fs);
	}
      fprintf(fp,"%.6f\n",sj);
    }

  /* Make note 3 */
  f3 = f*3.0/2.0;
  for (i = 0; i < Nt; i++)
    {
      sj = 0.0;
      for (j = 0; j < nharm; j++)
	{
	  jh = j + 1;
 	  sj += An[j]*exp(-gam*jh*i/fs)*sin(2.0*M_PI*i*f3*dfn[j]*jh/fs);
	}
      fprintf(fp,"%.6f\n",sj);
    }
  
  /* Make note 4*/
  f4 = f*2.0;
  for (i = 0; i < Nt; i++)
    {
      sj = 0.0;
      for (j = 0; j < nharm; j++)
	{
	  jh = j + 1;
 	  sj += An[j]*exp(-gam*jh*i/fs)*sin(2.0*M_PI*i*f4*dfn[j]*jh/fs);
	}
      fprintf(fp,"%.6f\n",sj);
    }

  /* Play a chord */
  for (i = 0; i < 4*Nt; i++)
    {
      sj = 0.0;
      for (j = 0; j < nharm; j++)
	{
	  jh = j + 1;
 	  sj += .22*An[j]*exp(-gam*jh*i/fs)*sin(2.0*M_PI*i*f1*dfn[j]*jh/fs);
 	  sj += .22*An[j]*exp(-gam*jh*i/fs)*sin(2.0*M_PI*i*f2*dfn[j]*jh/fs);
 	  sj += .22*An[j]*exp(-gam*jh*i/fs)*sin(2.0*M_PI*i*f3*dfn[j]*jh/fs);
 	  sj += .22*An[j]*exp(-gam*jh*i/fs)*sin(2.0*M_PI*i*f4*dfn[j]*jh/fs);
	}
      fprintf(fp,"%.6f\n",sj);
    }
  
  
  fclose(fp);

      

  
}
